netapp_ontap.models.lun_copy_source API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_copy_source`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunCopySourceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunCopySource object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the lun_copy_source.

  `max_throughput: Size GET POST PATCH`

    The maximum data throughput, in bytes per second, that should be utilized in support of the LUN copy. This property can be used to throttle a transfer and limit its impact on the performance of the source and destination nodes. The specified value will be rounded up to the nearest megabyte.
    If this property is not specified in a POST that begins a LUN copy, throttling is not applied to the data transfer.
    For more information, see Size properties in the docs section of the ONTAP REST API documentation.
    Valid only in a POST that begins a LUN copy or a PATCH when a LUN copy is already in process.

  `name: str GET POST`

    The fully qualified path of the LUN copy source composed of a "/vol" prefix, the volume name, the optional qtree name, and base name of the LUN.
    Set this property in POST to specify the source for a LUN copy operation.

    Example: /vol/vol2/lun1

  `peer: SvmPeer GET POST PATCH`

    The peer field of the lun_copy_source.

  `progress: LunCopySourceProgress GET PATCH`

    Properties related to the progress of an active or recently completed LUN copy.

  `uuid: str GET POST`

    The unique identifier of the LUN copy source.
    Set this property in POST to specify the source for a LUN copy operation.

    Example: 03c05019-40d9-3945-c767-dca4c3be5e90